const pRequest = require("./pRequest");

const requestURL = "http://api.trkd.thomsonreuters.com/api/Fundamentals/Fundamentals.svc/REST/Fundamentals_1/GetFinancialStatementsReports_1";


var finObj = module.exports = {
	// send trkd request, get a promise back with a json message
	getStatementsJSON: (ric) => {
		if(!global.token)
			return Promise.reject("Unable to get quotes, Authorization token not available");
		
		const finMsg = {
			"GetFinancialStatementsReports_Request_1": {
				"companyId": ric,
				"companyIdType": "RIC"
				}
			};
		
		const opt = {
			url: requestURL,
			headers: {
				"content-type": "application/json;charset=utf-8",
				"X-Trkd-Auth-ApplicationID": global.applicationID,
				"X-Trkd-Auth-Token": global.token
			},
			body: JSON.stringify(finMsg)
		};

		return pRequest.sendRequest(opt)
			.then(resp => resp.GetFinancialStatementsReports_Response_1.FundamentalReports.ReportFinancialStatements);
	},
	
	
	sim: (ric) => new Promise(res => { res({"Major":1,"Minor":0,"Revision":1,"CoIDs":{"CoID":[{"Type":"RepNo","Value":"A489F"},{"Type":"CompanyName","Value":"Thomson Reuters Corp"},{"Type":"IRSNo","Value":"980176673"},{"Type":"CIKNo","Value":"0001075124"}]},"Issues":{"Issue":[{"ID":1,"Type":"C","Desc":"Common Stock","Order":1,"IssueID":[{"Type":"Name","Value":"Ordinary Shares"},{"Type":"Ticker","Value":"TRI"},{"Type":"RIC","Value":"TRI"},{"Type":"DisplayRIC","Value":"TRI.N"},{"Type":"InstrumentPI","Value":"277618"},{"Type":"QuotePI","Value":"748450"}],"Exchange":{"Code":"NYSE","Country":"USA","Value":"New York Stock Exchange"},"GlobalListingType":{"Value":"CCR"}}]},"CoGeneralInfo":{"CoStatus":{"Code":1,"Value":"Active"},"CoType":{"Code":"EQU","Value":"Equity Issue"},"LastModified":"2017-11-04","LatestAvailableAnnual":"2016-12-31","LatestAvailableInterim":"2017-09-30","ReportingCurrency":{"Code":"USD","Value":"U.S. Dollars"},"MostRecentExchange":{"Date":"2017-11-03","Value":"1.0"}},"Notes":{"CFAAvailability":{"Code":true},"IAvailability":{"Code":true},"ISIAvailability":{"Code":true},"BSIAvailability":{"Code":true},"CFIAvailability":{"Code":true}},"FinancialStatements":{"COAMap":{"mapItem":[{"coaItem":"SREV","statementType":"INC","lineID":100,"precision":1,"Value":"Revenue"},{"coaItem":"SORE","statementType":"INC","lineID":300,"precision":1,"Value":"Other Revenue, Total"},{"coaItem":"RTLR","statementType":"INC","lineID":310,"precision":1,"Value":"Total Revenue"},{"coaItem":"SCOR","statementType":"INC","lineID":360,"precision":1,"Value":"Cost of Revenue, Total"},{"coaItem":"SGRP","statementType":"INC","lineID":370,"precision":1,"Value":"Gross Profit"},{"coaItem":"SSGA","statementType":"INC","lineID":550,"precision":1,"Value":"Selling/General/Admin. Expenses, Total"},{"coaItem":"ERAD","statementType":"INC","lineID":560,"precision":1,"Value":"Research & Development"},{"coaItem":"SDPR","statementType":"INC","lineID":600,"precision":1,"Value":"Depreciation/Amortization"},{"coaItem":"SINN","statementType":"INC","lineID":671,"precision":1,"Value":"Interest Exp.(Inc.),Net-Operating, Total"},{"coaItem":"SUIE","statementType":"INC","lineID":740,"precision":1,"Value":"Unusual Expense (Income)"},{"coaItem":"SOOE","statementType":"INC","lineID":820,"precision":1,"Value":"Other Operating Expenses, Total"},{"coaItem":"ETOE","statementType":"INC","lineID":830,"precision":1,"Value":"Total Operating Expense"},{"coaItem":"SOPI","statementType":"INC","lineID":840,"precision":1,"Value":"Operating Income"},{"coaItem":"SNIN","statementType":"INC","lineID":911,"precision":1,"Value":"Interest Inc.(Exp.),Net-Non-Op., Total"},{"coaItem":"NGLA","statementType":"INC","lineID":920,"precision":1,"Value":"Gain (Loss) on Sale of Assets"},{"coaItem":"SONT","statementType":"INC","lineID":1270,"precision":1,"Value":"Other, Net"},{"coaItem":"EIBT","statementType":"INC","lineID":1280,"precision":1,"Value":"Net Income Before Taxes"},{"coaItem":"TTAX","statementType":"INC","lineID":1290,"precision":1,"Value":"Provision for Income Taxes"},{"coaItem":"TIAT","statementType":"INC","lineID":1300,"precision":1,"Value":"Net Income After Taxes"},{"coaItem":"CMIN","statementType":"INC","lineID":1310,"precision":1,"Value":"Minority Interest"},{"coaItem":"CEIA","statementType":"INC","lineID":1320,"precision":1,"Value":"Equity In Affiliates"},{"coaItem":"CGAP","statementType":"INC","lineID":1330,"precision":1,"Value":"U.S. GAAP Adjustment"},{"coaItem":"NIBX","statementType":"INC","lineID":1340,"precision":1,"Value":"Net Income Before Extra. Items"},{"coaItem":"STXI","statementType":"INC","lineID":1390,"precision":1,"Value":"Total Extraordinary Items"},{"coaItem":"NINC","statementType":"INC","lineID":1400,"precision":1,"Value":"Net Income"},{"coaItem":"SANI","statementType":"INC","lineID":1460,"precision":1,"Value":"Total Adjustments to Net Income"},{"coaItem":"CIAC","statementType":"INC","lineID":1470,"precision":1,"Value":"Income Available to Com Excl ExtraOrd"},{"coaItem":"XNIC","statementType":"INC","lineID":1480,"precision":1,"Value":"Income Available to Com Incl ExtraOrd"},{"coaItem":"SDAJ","statementType":"INC","lineID":1520,"precision":1,"Value":"Dilution Adjustment"},{"coaItem":"SDNI","statementType":"INC","lineID":1530,"precision":1,"Value":"Diluted Net Income"},{"coaItem":"SDWS","statementType":"INC","lineID":1540,"precision":2,"Value":"Diluted Weighted Average Shares"},{"coaItem":"SDBF","statementType":"INC","lineID":1550,"precision":3,"Value":"Diluted EPS Excluding ExtraOrd Items"},{"coaItem":"DDPS1","statementType":"INC","lineID":1570,"precision":3,"Value":"DPS - Common Stock Primary Issue"},{"coaItem":"VDES","statementType":"INC","lineID":1770,"precision":3,"Value":"Diluted Normalized EPS"},{"coaItem":"ACSH","statementType":"BAL","lineID":10,"precision":1,"Value":"Cash"},{"coaItem":"ACAE","statementType":"BAL","lineID":20,"precision":1,"Value":"Cash & Equivalents"},{"coaItem":"ASTI","statementType":"BAL","lineID":30,"precision":1,"Value":"Short Term Investments"},{"coaItem":"SCSI","statementType":"BAL","lineID":40,"precision":1,"Value":"Cash and Short Term Investments"},{"coaItem":"AACR","statementType":"BAL","lineID":70,"precision":1,"Value":"Accounts Receivable - Trade, Net"},{"coaItem":"ATRC","statementType":"BAL","lineID":100,"precision":1,"Value":"Total Receivables, Net"},{"coaItem":"AITL","statementType":"BAL","lineID":180,"precision":1,"Value":"Total Inventory"},{"coaItem":"APPY","statementType":"BAL","lineID":190,"precision":1,"Value":"Prepaid Expenses"},{"coaItem":"SOCA","statementType":"BAL","lineID":260,"precision":1,"Value":"Other Current Assets, Total"},{"coaItem":"ATCA","statementType":"BAL","lineID":270,"precision":1,"Value":"Total Current Assets"},{"coaItem":"APTC","statementType":"BAL","lineID":520,"precision":1,"Value":"Property/Plant/Equipment, Total - Gross"},{"coaItem":"ADEP","statementType":"BAL","lineID":530,"precision":1,"Value":"Accumulated Depreciation, Total"},{"coaItem":"APPN","statementType":"BAL","lineID":540,"precision":1,"Value":"Property/Plant/Equipment, Total - Net"},{"coaItem":"AGWI","statementType":"BAL","lineID":570,"precision":1,"Value":"Goodwill, Net"},{"coaItem":"AINT","statementType":"BAL","lineID":600,"precision":1,"Value":"Intangibles, Net"},{"coaItem":"SINV","statementType":"BAL","lineID":690,"precision":1,"Value":"Long Term Investments"},{"coaItem":"ALTR","statementType":"BAL","lineID":710,"precision":1,"Value":"Note Receivable - Long Term"},{"coaItem":"SOLA","statementType":"BAL","lineID":780,"precision":1,"Value":"Other Long Term Assets, Total"},{"coaItem":"ATOT","statementType":"BAL","lineID":880,"precision":1,"Value":"Total Assets"},{"coaItem":"LAPB","statementType":"BAL","lineID":890,"precision":1,"Value":"Accounts Payable"},{"coaItem":"LPBA","statementType":"BAL","lineID":900,"precision":1,"Value":"Payable/Accrued"},{"coaItem":"LAEX","statementType":"BAL","lineID":910,"precision":1,"Value":"Accrued Expenses"},{"coaItem":"LSTD","statementType":"BAL","lineID":1120,"precision":1,"Value":"Notes Payable/Short Term Debt"},{"coaItem":"LCLD","statementType":"BAL","lineID":1130,"precision":1,"Value":"Current Port. of LT Debt/Capital Leases"},{"coaItem":"SOCL","statementType":"BAL","lineID":1220,"precision":1,"Value":"Other Current liabilities, Total"},{"coaItem":"LTCL","statementType":"BAL","lineID":1230,"precision":1,"Value":"Total Current Liabilities"},{"coaItem":"LLTD","statementType":"BAL","lineID":1240,"precision":1,"Value":"Long Term Debt"},{"coaItem":"LCLO","statementType":"BAL","lineID":1250,"precision":1,"Value":"Capital Lease Obligations"},{"coaItem":"LTTD","statementType":"BAL","lineID":1260,"precision":1,"Value":"Total Long Term Debt"},{"coaItem":"STLD","statementType":"BAL","lineID":1270,"precision":1,"Value":"Total Debt"},{"coaItem":"SBDT","statementType":"BAL","lineID":1300,"precision":1,"Value":"Deferred Income Tax"},{"coaItem":"LMIN","statementType":"BAL","lineID":1310,"precision":1,"Value":"Minority Interest"},{"coaItem":"SLTL","statementType":"BAL","lineID":1370,"precision":1,"Value":"Other Liabilities, Total"},{"coaItem":"LTLL","statementType":"BAL","lineID":1380,"precision":1,"Value":"Total Liabilities"},{"coaItem":"SRPR","statementType":"BAL","lineID":1410,"precision":1,"Value":"Redeemable Preferred Stock, Total"},{"coaItem":"SPRS","statementType":"BAL","lineID":1460,"precision":1,"Value":"Preferred Stock - Non Redeemable, Net"},{"coaItem":"SCMS","statementType":"BAL","lineID":1490,"precision":1,"Value":"Common Stock, Total"},{"coaItem":"QPIC","statementType":"BAL","lineID":1500,"precision":1,"Value":"Additional Paid-In Capital"},{"coaItem":"QRED","statementType":"BAL","lineID":1510,"precision":1,"Value":"Retained Earnings (Accumulated Deficit)"},{"coaItem":"QTSC","statementType":"BAL","lineID":1520,"precision":1,"Value":"Treasury Stock - Common"},{"coaItem":"QEDG","statementType":"BAL","lineID":1530,"precision":1,"Value":"ESOP Debt Guarantee"},{"coaItem":"QUGL","statementType":"BAL","lineID":1540,"precision":1,"Value":"Unrealized Gain (Loss)"},{"coaItem":"SOTE","statementType":"BAL","lineID":1590,"precision":1,"Value":"Other Equity, Total"},{"coaItem":"QTLE","statementType":"BAL","lineID":1600,"precision":1,"Value":"Total Equity"},{"coaItem":"QTEL","statementType":"BAL","lineID":1610,"precision":1,"Value":"Total Liabilities & Shareholders' Equity"},{"coaItem":"QTCO","statementType":"BAL","lineID":1660,"precision":2,"Value":"Total Common Shares Outstanding"},{"coaItem":"QTPO","statementType":"BAL","lineID":1770,"precision":2,"Value":"Total Preferred Shares Outstanding"},{"coaItem":"STBP","statementType":"BAL","lineID":1980,"precision":3,"Value":"Tangible Book Value per Share, Common Eq"},{"coaItem":"ONET","statementType":"CAS","lineID":10,"precision":1,"Value":"Net Income/Starting Line"},{"coaItem":"SDED","statementType":"CAS","lineID":40,"precision":1,"Value":"Depreciation/Depletion"},{"coaItem":"SAMT","statementType":"CAS","lineID":80,"precision":1,"Value":"Amortization"},{"coaItem":"OBDT","statementType":"CAS","lineID":90,"precision":1,"Value":"Deferred Taxes"},{"coaItem":"SNCI","statementType":"CAS","lineID":170,"precision":1,"Value":"Non-Cash Items"},{"coaItem":"SOCF","statementType":"CAS","lineID":470,"precision":1,"Value":"Changes in Working Capital"},{"coaItem":"OTLO","statementType":"CAS","lineID":480,"precision":1,"Value":"Cash from Operating Activities"},{"coaItem":"SCEX","statementType":"CAS","lineID":520,"precision":1,"Value":"Capital Expenditures"},{"coaItem":"SICF","statementType":"CAS","lineID":670,"precision":1,"Value":"Other Investing Cash Flow Items, Total"},{"coaItem":"ITLI","statementType":"CAS","lineID":680,"precision":1,"Value":"Cash from Investing Activities"},{"coaItem":"SFCF","statementType":"CAS","lineID":730,"precision":1,"Value":"Financing Cash Flow Items"},{"coaItem":"FCDP","statementType":"CAS","lineID":760,"precision":1,"Value":"Total Cash Dividends Paid"},{"coaItem":"FPSS","statementType":"CAS","lineID":880,"precision":1,"Value":"Issuance (Retirement) of Stock, Net"},{"coaItem":"FPRD","statementType":"CAS","lineID":970,"precision":1,"Value":"Issuance (Retirement) of Debt, Net"},{"coaItem":"FTLF","statementType":"CAS","lineID":980,"precision":1,"Value":"Cash from Financing Activities"},{"coaItem":"SFEE","statementType":"CAS","lineID":990,"precision":1,"Value":"Foreign Exchange Effects"},{"coaItem":"SNCC","statementType":"CAS","lineID":1000,"precision":1,"Value":"Net Change in Cash"},{"coaItem":"SCIP","statementType":"CAS","lineID":1040,"precision":1,"Value":"Cash Interest Paid"},{"coaItem":"SCTP","statementType":"CAS","lineID":1050,"precision":1,"Value":"Cash Taxes Paid"}]},"AnnualPeriods":{"FiscalPeriod":[{"Type":"Annual","EndDate":"2016-12-31","FiscalYear":"2016","Statement":[{"Type":"INC","FPHeader":{"PeriodLength":12,"periodType":{"Code":"M","Value":"Months"},"UpdateType":{"Code":"UPD","Value":"Updated Normal"},"StatementDate":"2016-12-31","AuditorName":{"Code":"PWCL","Value":"PricewaterhouseCoopers LLP"},"AuditorOpinion":{"Code":"UNQ","Value":"Unqualified"},"Source":{"Date":"2017-03-09","Value":"ARS"}},"lineItem":[{"coaCode":"SREV","Value":"11166.000000"},{"coaCode":"RTLR","Value":"11166.000000"},{"coaCode":"SCOR","Value":"836.000000"},{"coaCode":"SGRP","Value":"10330.000000"},{"coaCode":"SSGA","Value":"7376.000000"},{"coaCode":"SDPR","Value":"1552.000000"},{"coaCode":"SINN","Value":"20.000000"},{"coaCode":"SUIE","Value":"-31.000000"},{"coaCode":"SOOE","Value":"23.000000"},{"coaCode":"ETOE","Value":"9776.000000"},{"coaCode":"SOPI","Value":"1390.000000"},{"coaCode":"SNIN","Value":"-287.000000"},{"coaCode":"SONT","Value":"-66.000000"},{"coaCode":"EIBT","Value":"1037.000000"},{"coaCode":"TTAX","Value":"-15.000000"},{"coaCode":"TIAT","Value":"1052.000000"},{"coaCode":"CMIN","Value":"-51.000000"},{"coaCode":"CEIA","Value":"4.000000"},{"coaCode":"NIBX","Value":"1005.000000"},{"coaCode":"STXI","Value":"2093.000000"},{"coaCode":"NINC","Value":"3098.000000"},{"coaCode":"SANI","Value":"-2.000000"},{"coaCode":"CIAC","Value":"1003.000000"},{"coaCode":"XNIC","Value":"3096.000000"},{"coaCode":"SDNI","Value":"3096.000000"},{"coaCode":"SDWS","Value":"748.961490"},{"coaCode":"SDBF","Value":"1.339190"},{"coaCode":"DDPS1","Value":"1.360000"},{"coaCode":"VDES","Value":"1.496270"}]},{"Type":"BAL","FPHeader":{"UpdateType":{"Code":"UPD","Value":"Updated Normal"},"StatementDate":"2016-12-31","AuditorName":{"Code":"PWCL","Value":"PricewaterhouseCoopers LLP"},"AuditorOpinion":{"Code":"UNQ","Value":"Unqualified"},"Source":{"Date":"2017-03-09","Value":"ARS"}},"lineItem":[{"coaCode":"ACSH","Value":"590.000000"},{"coaCode":"ACAE","Value":"1778.000000"},{"coaCode":"ASTI","Value":"67.000000"},{"coaCode":"SCSI","Value":"2435.000000"},{"coaCode":"AACR","Value":"1327.000000"},{"coaCode":"ATRC","Value":"1465.000000"},{"coaCode":"AITL","Value":"32.000000"},{"coaCode":"APPY","Value":"316.000000"},{"coaCode":"SOCA","Value":"386.000000"},{"coaCode":"ATCA","Value":"4634.000000"},{"coaCode":"APTC","Value":"4075.000000"},{"coaCode":"ADEP","Value":"-3114.000000"},{"coaCode":"APPN","Value":"961.000000"},{"coaCode":"AGWI","Value":"14485.000000"},{"coaCode":"AINT","Value":"7049.000000"},{"coaCode":"SINV","Value":"251.000000"},{"coaCode":"SOLA","Value":"472.000000"},{"coaCode":"ATOT","Value":"27852.000000"},{"coaCode":"LAPB","Value":"311.000000"},{"coaCode":"LAEX","Value":"1517.000000"},{"coaCode":"LSTD","Value":"0.000000"},{"coaCode":"LCLD","Value":"1179.000000"},{"coaCode":"SOCL","Value":"1555.000000"},{"coaCode":"LTCL","Value":"4562.000000"},{"coaCode":"LLTD","Value":"6279.000000"},{"coaCode":"LTTD","Value":"6279.000000"},{"coaCode":"STLD","Value":"7458.000000"},{"coaCode":"SBDT","Value":"1158.000000"},{"coaCode":"LMIN","Value":"483.000000"},{"coaCode":"SLTL","Value":"2597.000000"},{"coaCode":"LTLL","Value":"15079.000000"},{"coaCode":"SRPR","Value":"110.000000"},{"coaCode":"SCMS","Value":"9283.000000"},{"coaCode":"QPIC","Value":"196.000000"},{"coaCode":"QRED","Value":"7477.000000"},{"coaCode":"SOTE","Value":"-4293.000000"},{"coaCode":"QTLE","Value":"12773.000000"},{"coaCode":"QTEL","Value":"27852.000000"},{"coaCode":"QTCO","Value":"727.443300"},{"coaCode":"QTPO","Value":"6.000000"},{"coaCode":"STBP","Value":"-12.194760"}]},{"Type":"CAS","FPHeader":{"PeriodLength":12,"periodType":{"Code":"M","Value":"Months"},"UpdateType":{"Code":"UPD","Value":"Updated Normal"},"StatementDate":"2016-12-31","AuditorName":{"Code":"PWCL","Value":"PricewaterhouseCoopers LLP"},"AuditorOpinion":{"Code":"UNQ","Value":"Unqualified"},"Source":{"Date":"2017-03-09","Value":"ARS"}},"lineItem":[{"coaCode":"ONET","Value":"1056.000000"},{"coaCode":"SDED","Value":"313.000000"},{"coaCode":"SAMT","Value":"1239.000000"},{"coaCode":"OBDT","Value":"-11.000000"},{"coaCode":"SNCI","Value":"369.000000"},{"coaCode":"SCTP","Value":"347.000000"},{"coaCode":"SCIP","Value":"347.000000"},{"coaCode":"SOCF","Value":"18.000000"},{"coaCode":"OTLO","Value":"2984.000000"},{"coaCode":"SCEX","Value":"-905.000000"},{"coaCode":"SICF","Value":"3091.000000"},{"coaCode":"ITLI","Value":"2186.000000"},{"coaCode":"SFCF","Value":"-14.000000"},{"coaCode":"FCDP","Value":"-982.000000"},{"coaCode":"FPSS","Value":"-1673.000000"},{"coaCode":"FPRD","Value":"-1043.000000"},{"coaCode":"FTLF","Value":"-3712.000000"},{"coaCode":"SFEE","Value":"-13.000000"},{"coaCode":"SNCC","Value":"1445.000000"}]}]},{"Type":"Annual","EndDate":"2015-12-31","FiscalYear":"2015","Statement":[{"Type":"INC","FPHeader":{"PeriodLength":12,"periodType":{"Code":"M","Value":"Months"},"UpdateType":{"Code":"RES","Value":"Restated Normal"},"StatementDate":"2016-12-31","AuditorName":{"Code":"PWCL","Value":"PricewaterhouseCoopers LLP"},"AuditorOpinion":{"Code":"UNQ","Value":"Unqualified"},"Source":{"Date":"2017-03-09","Value":"ARS"}},"lineItem":[{"coaCode":"SREV","Value":"11257.000000"},{"coaCode":"RTLR","Value":"11257.000000"},{"coaCode":"SCOR","Value":"885.000000"},{"coaCode":"SGRP","Value":"10372.000000"},{"coaCode":"SSGA","Value":"7283.000000"},{"coaCode":"SDPR","Value":"1582.000000"},{"coaCode":"SINN","Value":"-6.000000"},{"coaCode":"SUIE","Value":"-25.000000"},{"coaCode":"SOOE","Value":"12.000000"},{"coaCode":"ETOE","Value":"9731.000000"},{"coaCode":"SOPI","Value":"1526.000000"},{"coaCode":"SNIN","Value":"-308.000000"},{"coaCode":"SONT","Value":"-67.000000"},{"coaCode":"EIBT","Value":"1151.000000"},{"coaCode":"TTAX","Value":"34.000000"},{"coaCode":"TIAT","Value":"1117.000000"},{"coaCode":"CMIN","Value":"-56.000000"},{"coaCode":"CEIA","Value":"10.000000"},{"coaCode":"NIBX","Value":"1071.000000"},{"coaCode":"STXI","Value":"184.000000"},{"coaCode":"NINC","Value":"1255.000000"},{"coaCode":"SANI","Value":"-2.000000"},{"coaCode":"CIAC","Value":"1069.000000"},{"coaCode":"XNIC","Value":"1253.000000"},{"coaCode":"SDNI","Value":"1253.000000"},{"coaCode":"SDWS","Value":"784.138390"},{"coaCode":"SDBF","Value":"1.363280"},{"coaCode":"DDPS1","Value":"1.340000"},{"coaCode":"VDES","Value":"1.332340"}]},{"Type":"BAL","FPHeader":{"UpdateType":{"Code":"RES","Value":"Restated Normal"},"StatementDate":"2016-12-31","AuditorName":{"Code":"PWCL","Value":"PricewaterhouseCoopers LLP"},"AuditorOpinion":{"Code":"UNQ","Value":"Unqualified"},"Source":{"Date":"2017-03-09","Value":"ARS"}},"lineItem":[{"coaCode":"ACSH","Value":"662.000000"},{"coaCode":"ACAE","Value":"304.000000"},{"coaCode":"ASTI","Value":"55.000000"},{"coaCode":"SCSI","Value":"1021.000000"},{"coaCode":"AACR","Value":"1714.000000"},{"coaCode":"ATRC","Value":"1805.000000"},{"coaCode":"AITL","Value":"33.000000"},{"coaCode":"APPY","Value":"358.000000"},{"coaCode":"SOCA","Value":"340.000000"},{"coaCode":"ATCA","Value":"3557.000000"},{"coaCode":"APTC","Value":"4172.000000"},{"coaCode":"ADEP","Value":"-3105.000000"},{"coaCode":"APPN","Value":"1067.000000"},{"coaCode":"AGWI","Value":"15878.000000"},{"coaCode":"AINT","Value":"7903.000000"},{"coaCode":"SINV","Value":"265.000000"},{"coaCode":"SOLA","Value":"442.000000"},{"coaCode":"ATOT","Value":"29112.000000"},{"coaCode":"LAPB","Value":"282.000000"},{"coaCode":"LAEX","Value":"1520.000000"},{"coaCode":"LSTD","Value":"0.000000"},{"coaCode":"LCLD","Value":"1818.000000"},{"coaCode":"SOCL","Value":"1787.000000"},{"coaCode":"LTCL","Value":"5407.000000"},{"coaCode":"LLTD","Value":"6831.000000"},{"coaCode":"LTTD","Value":"6831.000000"},{"coaCode":"STLD","Value":"8649.000000"},{"coaCode":"SBDT","Value":"1265.000000"},{"coaCode":"LMIN","Value":"487.000000"},{"coaCode":"SLTL","Value":"2509.000000"},{"coaCode":"LTLL","Value":"16499.000000"},{"coaCode":"SRPR","Value":"110.000000"},{"coaCode":"SCMS","Value":"9576.000000"},{"coaCode":"QPIC","Value":"166.000000"},{"coaCode":"QRED","Value":"6458.000000"},{"coaCode":"SOTE","Value":"-3697.000000"},{"coaCode":"QTLE","Value":"12613.000000"},{"coaCode":"QTEL","Value":"29112.000000"},{"coaCode":"QTCO","Value":"764.594860"},{"coaCode":"QTPO","Value":"6.000000"},{"coaCode":"STBP","Value":"-14.750300"}]},{"Type":"CAS","FPHeader":{"PeriodLength":12,"periodType":{"Code":"M","Value":"Months"},"UpdateType":{"Code":"CLA","Value":"Reclassified Normal"},"StatementDate":"2016-12-31","AuditorName":{"Code":"PWCL","Value":"PricewaterhouseCoopers LLP"},"AuditorOpinion":{"Code":"UNQ","Value":"Unqualified"},"Source":{"Date":"2017-03-09","Value":"ARS"}},"lineItem":[{"coaCode":"ONET","Value":"1127.000000"},{"coaCode":"SDED","Value":"340.000000"},{"coaCode":"SAMT","Value":"1242.000000"},{"coaCode":"OBDT","Value":"-194.000000"},{"coaCode":"SNCI","Value":"509.000000"},{"coaCode":"SCTP","Value":"206.000000"},{"coaCode":"SCIP","Value":"374.000000"},{"coaCode":"SOCF","Value":"-186.000000"},{"coaCode":"OTLO","Value":"2838.000000"},{"coaCode":"SCEX","Value":"-951.000000"},{"coaCode":"SICF","Value":"15.000000"},{"coaCode":"ITLI","Value":"-936.000000"},{"coaCode":"SFCF","Value":"14.000000"},{"coaCode":"FCDP","Value":"-1015.000000"},{"coaCode":"FPSS","Value":"-1417.000000"},{"coaCode":"FPRD","Value":"447.000000"},{"coaCode":"FTLF","Value":"-1971.000000"},{"coaCode":"SFEE","Value":"-24.000000"},{"coaCode":"SNCC","Value":"-93.000000"}]}]},{"Type":"Annual","EndDate":"2014-12-31","FiscalYear":"2014","Statement":[{"Type":"INC","FPHeader":{"PeriodLength":12,"periodType":{"Code":"M","Value":"Months"},"UpdateType":{"Code":"UPD","Value":"Updated Normal"},"StatementDate":"2014-12-31","AuditorName":{"Code":"PWCL","Value":"PricewaterhouseCoopers LLP"},"AuditorOpinion":{"Code":"UNQ","Value":"Unqualified"},"Source":{"Date":"2015-03-13","Value":"40-F"}},"lineItem":[{"coaCode":"SREV","Value":"12607.000000"},{"coaCode":"RTLR","Value":"12607.000000"},{"coaCode":"SCOR","Value":"1009.000000"},{"coaCode":"SGRP","Value":"11598.000000"},{"coaCode":"SSGA","Value":"8156.000000"},{"coaCode":"SDPR","Value":"1822.000000"},{"coaCode":"SINN","Value":"-1022.000000"},{"coaCode":"SUIE","Value":"146.000000"},{"coaCode":"SOOE","Value":"-2.000000"},{"coaCode":"ETOE","Value":"10109.000000"},{"coaCode":"SOPI","Value":"2498.000000"},{"coaCode":"SNIN","Value":"-420.000000"},{"coaCode":"SONT","Value":"-60.000000"},{"coaCode":"EIBT","Value":"2018.000000"},{"coaCode":"TTAX","Value":"62.000000"},{"coaCode":"TIAT","Value":"1956.000000"},{"coaCode":"CMIN","Value":"-50.000000"},{"coaCode":"CEIA","Value":"3.000000"},{"coaCode":"NIBX","Value":"1909.000000"},{"coaCode":"STXI","Value":"0.000000"},{"coaCode":"NINC","Value":"1909.000000"},{"coaCode":"SANI","Value":"-3.000000"},{"coaCode":"CIAC","Value":"1906.000000"},{"coaCode":"XNIC","Value":"1906.000000"},{"coaCode":"SDAJ","Value":"0.000000"},{"coaCode":"SDNI","Value":"1906.000000"},{"coaCode":"SDWS","Value":"810.930100"},{"coaCode":"SDBF","Value":"2.350390"},{"coaCode":"DDPS1","Value":"1.320000"},{"coaCode":"VDES","Value":"2.628880"}]},{"Type":"BAL","FPHeader":{"UpdateType":{"Code":"UPD","Value":"Updated Normal"},"StatementDate":"2014-12-31","AuditorName":{"Code":"PWCL","Value":"PricewaterhouseCoopers LLP"},"AuditorOpinion":{"Code":"UNQ","Value":"Unqualified"},"Source":{"Date":"2015-03-13","Value":"40-F"}},"lineItem":[{"coaCode":"ACSH","Value":"633.000000"},{"coaCode":"ACAE","Value":"385.000000"},{"coaCode":"ASTI","Value":"161.000000"},{"coaCode":"SCSI","Value":"1179.000000"},{"coaCode":"AACR","Value":"1792.000000"},{"coaCode":"ATRC","Value":"1810.000000"},{"coaCode":"AITL","Value":"37.000000"},{"coaCode":"APPY","Value":"407.000000"},{"coaCode":"SOCA","Value":"213.000000"},{"coaCode":"ATCA","Value":"3646.000000"},{"coaCode":"APTC","Value":"4063.000000"},{"coaCode":"ADEP","Value":"-2881.000000"},{"coaCode":"APPN","Value":"1182.000000"},{"coaCode":"AGWI","Value":"16403.000000"},{"coaCode":"AINT","Value":"8653.000000"},{"coaCode":"SINV","Value":"300.000000"},{"coaCode":"SOLA","Value":"413.000000"},{"coaCode":"ATOT","Value":"30597.000000"},{"coaCode":"LAPB","Value":"411.000000"},{"coaCode":"LAEX","Value":"1578.000000"},{"coaCode":"LSTD","Value":"0.000000"},{"coaCode":"LCLD","Value":"714.000000"},{"coaCode":"SOCL","Value":"1894.000000"},{"coaCode":"LTCL","Value":"4597.000000"},{"coaCode":"LLTD","Value":"7615.000000"},{"coaCode":"LTTD","Value":"7615.000000"},{"coaCode":"STLD","Value":"8329.000000"},{"coaCode":"SBDT","Value":"1433.000000"},{"coaCode":"LMIN","Value":"481.000000"},{"coaCode":"SLTL","Value":"2293.000000"},{"coaCode":"LTLL","Value":"16419.000000"},{"coaCode":"SRPR","Value":"110.000000"},{"coaCode":"SCMS","Value":"9866.000000"},{"coaCode":"QPIC","Value":"181.000000"},{"coaCode":"QRED","Value":"6835.000000"},{"coaCode":"SOTE","Value":"-2814.000000"},{"coaCode":"QTLE","Value":"14178.000000"},{"coaCode":"QTEL","Value":"30597.000000"},{"coaCode":"QTCO","Value":"796.016210"},{"coaCode":"QTPO","Value":"6.000000"},{"coaCode":"STBP","Value":"-13.803740"}]},{"Type":"CAS","FPHeader":{"PeriodLength":12,"periodType":{"Code":"M","Value":"Months"},"UpdateType":{"Code":"CLA","Value":"Reclassified Normal"},"StatementDate":"2015-12-31","AuditorName":{"Code":"PWCL","Value":"PricewaterhouseCoopers LLP"},"AuditorOpinion":{"Code":"UNQ","Value":"Unqualified"},"Source":{"Date":"2016-03-08","Value":"ARS"}},"lineItem":[{"coaCode":"ONET","Value":"1959.000000"},{"coaCode":"SDED","Value":"397.000000"},{"coaCode":"SAMT","Value":"1425.000000"},{"coaCode":"OBDT","Value":"-273.000000"},{"coaCode":"SNCI","Value":"-710.000000"},{"coaCode":"SCTP","Value":"257.000000"},{"coaCode":"SCIP","Value":"389.000000"},{"coaCode":"SOCF","Value":"-384.000000"},{"coaCode":"OTLO","Value":"2414.000000"},{"coaCode":"SCEX","Value":"-968.000000"},{"coaCode":"SICF","Value":"-103.000000"},{"coaCode":"ITLI","Value":"-1071.000000"},{"coaCode":"SFCF","Value":"81.000000"},{"coaCode":"FCDP","Value":"-1036.000000"},{"coaCode":"FPSS","Value":"-1023.000000"},{"coaCode":"FPRD","Value":"360.000000"},{"coaCode":"FTLF","Value":"-1618.000000"},{"coaCode":"SFEE","Value":"-22.000000"},{"coaCode":"SNCC","Value":"-297.000000"}]}]},{"Type":"Annual","EndDate":"2013-12-31","FiscalYear":"2013","Statement":[{"Type":"INC","FPHeader":{"PeriodLength":12,"periodType":{"Code":"M","Value":"Months"},"UpdateType":{"Code":"UPD","Value":"Updated Normal"},"StatementDate":"2013-12-31","AuditorName":{"Code":"PWCL","Value":"PricewaterhouseCoopers LLP"},"AuditorOpinion":{"Code":"UNQ","Value":"Unqualified"},"Source":{"Date":"2014-03-12","Value":"40-F"}},"lineItem":[{"coaCode":"SREV","Value":"12702.000000"},{"coaCode":"RTLR","Value":"12702.000000"},{"coaCode":"SCOR","Value":"997.000000"},{"coaCode":"SGRP","Value":"11705.000000"},{"coaCode":"SSGA","Value":"8214.000000"},{"coaCode":"SDPR","Value":"1830.000000"},{"coaCode":"SINN","Value":"-14.000000"},{"coaCode":"SUIE","Value":"197.000000"},{"coaCode":"SOOE","Value":"-3.000000"},{"coaCode":"ETOE","Value":"11221.000000"},{"coaCode":"SOPI","Value":"1481.000000"},{"coaCode":"SNIN","Value":"-406.000000"},{"coaCode":"SONT","Value":"-72.000000"},{"coaCode":"EIBT","Value":"1003.000000"},{"coaCode":"TTAX","Value":"848.000000"},{"coaCode":"TIAT","Value":"155.000000"},{"coaCode":"CMIN","Value":"-48.000000"},{"coaCode":"CEIA","Value":"20.000000"},{"coaCode":"NIBX","Value":"127.000000"},{"coaCode":"STXI","Value":"10.000000"},{"coaCode":"NINC","Value":"137.000000"},{"coaCode":"SANI","Value":"-3.000000"},{"coaCode":"CIAC","Value":"124.000000"},{"coaCode":"XNIC","Value":"134.000000"},{"coaCode":"SDNI","Value":"134.000000"},{"coaCode":"SDWS","Value":"830.984680"},{"coaCode":"SDBF","Value":"0.149220"},{"coaCode":"DDPS1","Value":"1.300000"},{"coaCode":"VDES","Value":"0.412040"}]},{"Type":"BAL","FPHeader":{"UpdateType":{"Code":"UPD","Value":"Updated Normal"},"StatementDate":"2013-12-31","AuditorName":{"Code":"PWCL","Value":"PricewaterhouseCoopers LLP"},"AuditorOpinion":{"Code":"UNQ","Value":"Unqualified"},"Source":{"Date":"2014-03-12","Value":"40-F"}},"lineItem":[{"coaCode":"ACSH","Value":"428.000000"},{"coaCode":"ACAE","Value":"888.000000"},{"coaCode":"ASTI","Value":"104.000000"},{"coaCode":"SCSI","Value":"1420.000000"},{"coaCode":"AACR","Value":"1733.000000"},{"coaCode":"ATRC","Value":"1751.000000"},{"coaCode":"AITL","Value":"46.000000"},{"coaCode":"APPY","Value":"390.000000"},{"coaCode":"SOCA","Value":"293.000000"},{"coaCode":"ATCA","Value":"3900.000000"},{"coaCode":"APTC","Value":"3896.000000"},{"coaCode":"ADEP","Value":"-2605.000000"},{"coaCode":"APPN","Value":"1291.000000"},{"coaCode":"AGWI","Value":"16871.000000"},{"coaCode":"AINT","Value":"9512.000000"},{"coaCode":"SINV","Value":"309.000000"},{"coaCode":"SOLA","Value":"556.000000"},{"coaCode":"ATOT","Value":"32439.000000"},{"coaCode":"LAPB","Value":"406.000000"},{"coaCode":"LAEX","Value":"1626.000000"},{"coaCode":"LSTD","Value":"0.000000"},{"coaCode":"LCLD","Value":"789.000000"},{"coaCode":"SOCL","Value":"1940.000000"},{"coaCode":"LTCL","Value":"4761.000000"},{"coaCode":"LLTD","Value":"7470.000000"},{"coaCode":"LTTD","Value":"7470.000000"},{"coaCode":"STLD","Value":"8259.000000"},{"coaCode":"SBDT","Value":"1917.000000"},{"coaCode":"LMIN","Value":"394.000000"},{"coaCode":"SLTL","Value":"1861.000000"},{"coaCode":"LTLL","Value":"16403.000000"},{"coaCode":"SRPR","Value":"110.000000"},{"coaCode":"SCMS","Value":"10060.000000"},{"coaCode":"QPIC","Value":"177.000000"},{"coaCode":"QRED","Value":"7024.000000"},{"coaCode":"SOTE","Value":"-1335.000000"},{"coaCode":"QTLE","Value":"16036.000000"},{"coaCode":"QTEL","Value":"32439.000000"},{"coaCode":"QTCO","Value":"820.155830"},{"coaCode":"QTPO","Value":"6.000000"},{"coaCode":"STBP","Value":"-12.750020"}]},{"Type":"CAS","FPHeader":{"PeriodLength":12,"periodType":{"Code":"M","Value":"Months"},"UpdateType":{"Code":"RES","Value":"Restated Normal"},"StatementDate":"2014-12-31","AuditorName":{"Code":"PWCL","Value":"PricewaterhouseCoopers LLP"},"AuditorOpinion":{"Code":"UNQ","Value":"Unqualified"},"Source":{"Date":"2015-03-13","Value":"40-F"}},"lineItem":[{"coaCode":"ONET","Value":"185.000000"},{"coaCode":"SDED","Value":"416.000000"},{"coaCode":"SAMT","Value":"1414.000000"},{"coaCode":"OBDT","Value":"434.000000"},{"coaCode":"SNCI","Value":"-406.000000"},{"coaCode":"SCTP","Value":"334.000000"},{"coaCode":"SCIP","Value":"414.000000"},{"coaCode":"SOCF","Value":"60.000000"},{"coaCode":"OTLO","Value":"2103.000000"},{"coaCode":"SCEX","Value":"-1004.000000"},{"coaCode":"SICF","Value":"-618.000000"},{"coaCode":"ITLI","Value":"-1622.000000"},{"coaCode":"SFCF","Value":"-19.000000"},{"coaCode":"FCDP","Value":"-1041.000000"},{"coaCode":"FPSS","Value":"-400.000000"},{"coaCode":"FPRD","Value":"1028.000000"},{"coaCode":"FTLF","Value":"-432.000000"},{"coaCode":"SFEE","Value":"-13.000000"},{"coaCode":"SNCC","Value":"36.000000"}]}]},{"Type":"Annual","EndDate":"2012-12-31","FiscalYear":"2012","Statement":[{"Type":"INC","FPHeader":{"PeriodLength":12,"periodType":{"Code":"M","Value":"Months"},"UpdateType":{"Code":"CLA","Value":"Reclassified Normal"},"StatementDate":"2013-12-31","AuditorName":{"Code":"PWCL","Value":"PricewaterhouseCoopers LLP"},"AuditorOpinion":{"Code":"UNQ","Value":"Unqualified"},"Source":{"Date":"2014-03-12","Value":"40-F"}},"lineItem":[{"coaCode":"SREV","Value":"13132.000000"},{"coaCode":"RTLR","Value":"13132.000000"},{"coaCode":"SCOR","Value":"1026.000000"},{"coaCode":"SGRP","Value":"12106.000000"},{"coaCode":"SSGA","Value":"8648.000000"},{"coaCode":"SDPR","Value":"1735.000000"},{"coaCode":"SINN","Value":"36.000000"},{"coaCode":"SUIE","Value":"-84.000000"},{"coaCode":"SOOE","Value":"-799.000000"},{"coaCode":"ETOE","Value":"10562.000000"},{"coaCode":"SOPI","Value":"2570.000000"},{"coaCode":"SNIN","Value":"-350.000000"},{"coaCode":"SONT","Value":"-63.000000"},{"coaCode":"EIBT","Value":"2157.000000"},{"coaCode":"TTAX","Value":"126.000000"},{"coaCode":"TIAT","Value":"2031.000000"},{"coaCode":"CMIN","Value":"-53.000000"},{"coaCode":"CEIA","Value":"9.000000"},{"coaCode":"NIBX","Value":"1987.000000"},{"coaCode":"STXI","Value":"2.000000"},{"coaCode":"NINC","Value":"1989.000000"},{"coaCode":"SANI","Value":"-3.000000"},{"coaCode":"CIAC","Value":"1984.000000"},{"coaCode":"XNIC","Value":"1986.000000"},{"coaCode":"SDNI","Value":"1986.000000"},{"coaCode":"SDWS","Value":"829.603780"},{"coaCode":"SDBF","Value":"2.391500"},{"coaCode":"DDPS1","Value":"1.280000"},{"coaCode":"VDES","Value":"2.453930"}]},{"Type":"BAL","FPHeader":{"UpdateType":{"Code":"CLA","Value":"Reclassified Normal"},"StatementDate":"2013-12-31","AuditorName":{"Code":"PWCL","Value":"PricewaterhouseCoopers LLP"},"AuditorOpinion":{"Code":"UNQ","Value":"Unqualified"},"Source":{"Date":"2014-03-12","Value":"40-F"}},"lineItem":[{"coaCode":"ACSH","Value":"309.000000"},{"coaCode":"ACAE","Value":"974.000000"},{"coaCode":"ASTI","Value":"71.000000"},{"coaCode":"SCSI","Value":"1354.000000"},{"coaCode":"AACR","Value":"1795.000000"},{"coaCode":"ATRC","Value":"1818.000000"},{"coaCode":"AITL","Value":"55.000000"},{"coaCode":"APPY","Value":"347.000000"},{"coaCode":"SOCA","Value":"539.000000"},{"coaCode":"ATCA","Value":"4113.000000"},{"coaCode":"APTC","Value":"4099.000000"},{"coaCode":"ADEP","Value":"-2683.000000"},{"coaCode":"APPN","Value":"1416.000000"},{"coaCode":"AGWI","Value":"16251.000000"},{"coaCode":"AINT","Value":"9793.000000"},{"coaCode":"SINV","Value":"346.000000"},{"coaCode":"SOLA","Value":"618.000000"},{"coaCode":"ATOT","Value":"32537.000000"},{"coaCode":"LAPB","Value":"461.000000"},{"coaCode":"LAEX","Value":"1745.000000"},{"coaCode":"LSTD","Value":"0.000000"},{"coaCode":"LCLD","Value":"1103.000000"},{"coaCode":"SOCL","Value":"1663.000000"},{"coaCode":"LTCL","Value":"4972.000000"},{"coaCode":"LLTD","Value":"6223.000000"},{"coaCode":"LTTD","Value":"6223.000000"},{"coaCode":"STLD","Value":"7326.000000"},{"coaCode":"SBDT","Value":"1305.000000"},{"coaCode":"LMIN","Value":"353.000000"},{"coaCode":"SLTL","Value":"2539.000000"},{"coaCode":"LTLL","Value":"15392.000000"},{"coaCode":"SRPR","Value":"110.000000"},{"coaCode":"SCMS","Value":"10091.000000"},{"coaCode":"QPIC","Value":"170.000000"},{"coaCode":"QRED","Value":"8158.000000"},{"coaCode":"SOTE","Value":"-1384.000000"},{"coaCode":"QTLE","Value":"17145.000000"},{"coaCode":"QTEL","Value":"32537.000000"},{"coaCode":"QTCO","Value":"826.902060"},{"coaCode":"QTPO","Value":"6.000000"},{"coaCode":"STBP","Value":"-10.894880"}]},{"Type":"CAS","FPHeader":{"PeriodLength":12,"periodType":{"Code":"M","Value":"Months"},"UpdateType":{"Code":"CLA","Value":"Reclassified Normal"},"StatementDate":"2013-12-31","AuditorName":{"Code":"PWCL","Value":"PricewaterhouseCoopers LLP"},"AuditorOpinion":{"Code":"UNQ","Value":"Unqualified"},"Source":{"Date":"2014-03-12","Value":"40-F"}},"lineItem":[{"coaCode":"ONET","Value":"2042.000000"},{"coaCode":"SDED","Value":"425.000000"},{"coaCode":"SAMT","Value":"1310.000000"},{"coaCode":"OBDT","Value":"-149.000000"},{"coaCode":"SNCI","Value":"-811.000000"},{"coaCode":"SCTP","Value":"446.000000"},{"coaCode":"SCIP","Value":"419.000000"},{"coaCode":"SOCF","Value":"-159.000000"},{"coaCode":"OTLO","Value":"2658.000000"},{"coaCode":"SCEX","Value":"-964.000000"},{"coaCode":"SICF","Value":"736.000000"},{"coaCode":"ITLI","Value":"-228.000000"},{"coaCode":"SFCF","Value":"65.000000"},{"coaCode":"FCDP","Value":"-1024.000000"},{"coaCode":"FPSS","Value":"-168.000000"},{"coaCode":"FPRD","Value":"-424.000000"},{"coaCode":"FTLF","Value":"-1551.000000"},{"coaCode":"SFEE","Value":"0.000000"},{"coaCode":"SNCC","Value":"879.000000"}]}]},{"Type":"Annual","EndDate":"2011-12-31","FiscalYear":"2011","Statement":[{"Type":"INC","FPHeader":{"PeriodLength":12,"periodType":{"Code":"M","Value":"Months"},"UpdateType":{"Code":"RES","Value":"Restated Normal"},"StatementDate":"2013-03-31","Source":{"Date":"2013-05-02","Value":"6-K"}},"lineItem":[{"coaCode":"SREV","Value":"13650.000000"},{"coaCode":"RTLR","Value":"13650.000000"},{"coaCode":"SDPR","Value":"1695.000000"},{"coaCode":"SUIE","Value":"2806.000000"},{"coaCode":"SOOE","Value":"9927.000000"},{"coaCode":"ETOE","Value":"14428.000000"},{"coaCode":"SOPI","Value":"-778.000000"},{"coaCode":"SNIN","Value":"-408.000000"},{"coaCode":"EIBT","Value":"-1186.000000"},{"coaCode":"TTAX","Value":"271.000000"},{"coaCode":"TIAT","Value":"-1457.000000"},{"coaCode":"CMIN","Value":"2.000000"},{"coaCode":"NIBX","Value":"-1455.000000"},{"coaCode":"STXI","Value":"4.000000"},{"coaCode":"NINC","Value":"-1451.000000"},{"coaCode":"SANI","Value":"-3.000000"},{"coaCode":"CIAC","Value":"-1458.000000"},{"coaCode":"XNIC","Value":"-1454.000000"},{"coaCode":"SDAJ","Value":"0.000000"},{"coaCode":"SDNI","Value":"-1454.000000"},{"coaCode":"SDWS","Value":"835.800000"},{"coaCode":"SDBF","Value":"-1.744440"},{"coaCode":"DDPS1","Value":"1.240000"},{"coaCode":"VDES","Value":"0.604990"}]},{"Type":"BAL","FPHeader":{"UpdateType":{"Code":"UPD","Value":"Updated Normal"},"StatementDate":"2011-12-31","AuditorName":{"Code":"PWCL","Value":"PricewaterhouseCoopers LLP"},"AuditorOpinion":{"Code":"UNQ","Value":"Unqualified"},"Source":{"Date":"2012-03-19","Value":"40-F"}},"lineItem":[{"coaCode":"ACSH","Value":"249.000000"},{"coaCode":"ACAE","Value":"110.000000"},{"coaCode":"ASTI","Value":"63.000000"},{"coaCode":"SCSI","Value":"422.000000"},{"coaCode":"AACR","Value":"1966.000000"},{"coaCode":"ATRC","Value":"1984.000000"},{"coaCode":"AITL","Value":"66.000000"},{"coaCode":"APPY","Value":"372.000000"},{"coaCode":"SOCA","Value":"1070.000000"},{"coaCode":"ATCA","Value":"3914.000000"},{"coaCode":"APTC","Value":"3931.000000"},{"coaCode":"ADEP","Value":"-2422.000000"},{"coaCode":"APPN","Value":"1509.000000"},{"coaCode":"AGWI","Value":"15932.000000"},{"coaCode":"AINT","Value":"10111.000000"},{"coaCode":"SINV","Value":"253.000000"},{"coaCode":"SOLA","Value":"757.000000"},{"coaCode":"ATOT","Value":"32476.000000"},{"coaCode":"LAPB","Value":"508.000000"},{"coaCode":"LAEX","Value":"1756.000000"},{"coaCode":"LSTD","Value":"0.000000"},{"coaCode":"LCLD","Value":"434.000000"},{"coaCode":"SOCL","Value":"1906.000000"},{"coaCode":"LTCL","Value":"4604.000000"},{"coaCode":"LLTD","Value":"7160.000000"},{"coaCode":"LTTD","Value":"7160.000000"},{"coaCode":"STLD","Value":"7594.000000"},{"coaCode":"SBDT","Value":"1422.000000"},{"coaCode":"LMIN","Value":"345.000000"},{"coaCode":"SLTL","Value":"2540.000000"},{"coaCode":"LTLL","Value":"16071.000000"},{"coaCode":"SRPR","Value":"110.000000"},{"coaCode":"SCMS","Value":"10024.000000"},{"coaCode":"QPIC","Value":"154.000000"},{"coaCode":"QRED","Value":"7633.000000"},{"coaCode":"QUGL","Value":"-22.000000"},{"coaCode":"SOTE","Value":"-1494.000000"},{"coaCode":"QTLE","Value":"16405.000000"},{"coaCode":"QTEL","Value":"32476.000000"},{"coaCode":"QTCO","Value":"827.867630"},{"coaCode":"QTPO","Value":"6.000000"},{"coaCode":"STBP","Value":"-11.774830"}]},{"Type":"CAS","FPHeader":{"PeriodLength":12,"periodType":{"Code":"M","Value":"Months"},"UpdateType":{"Code":"UPD","Value":"Updated Normal"},"StatementDate":"2011-12-31","AuditorName":{"Code":"PWCL","Value":"PricewaterhouseCoopers LLP"},"AuditorOpinion":{"Code":"UNQ","Value":"Unqualified"},"Source":{"Date":"2012-03-19","Value":"40-F"}},"lineItem":[{"coaCode":"ONET","Value":"-1392.000000"},{"coaCode":"SDED","Value":"438.000000"},{"coaCode":"SAMT","Value":"1271.000000"},{"coaCode":"OBDT","Value":"-202.000000"},{"coaCode":"SNCI","Value":"2761.000000"},{"coaCode":"SCTP","Value":"511.000000"},{"coaCode":"SCIP","Value":"399.000000"},{"coaCode":"SOCF","Value":"-279.000000"},{"coaCode":"OTLO","Value":"2597.000000"},{"coaCode":"SCEX","Value":"-1041.000000"},{"coaCode":"SICF","Value":"-766.000000"},{"coaCode":"ITLI","Value":"-1807.000000"},{"coaCode":"SFCF","Value":"-39.000000"},{"coaCode":"FCDP","Value":"-963.000000"},{"coaCode":"FPSS","Value":"-326.000000"},{"coaCode":"FPRD","Value":"101.000000"},{"coaCode":"FTLF","Value":"-1227.000000"},{"coaCode":"SFEE","Value":"-5.000000"},{"coaCode":"SNCC","Value":"-442.000000"}]}]}]},"InterimPeriods":{"FiscalPeriod":[{"Type":"Interim","EndDate":"2017-09-30","FiscalYear":"2017","FiscalPeriodNumber":3,"Statement":[{"Type":"INC","FPHeader":{"PeriodLength":3,"periodType":{"Code":"M","Value":"Months"},"UpdateType":{"Code":"UPD","Value":"Updated Normal"},"StatementDate":"2017-09-30","Source":{"Date":"2017-11-03","Value":"Interim Report"}},"lineItem":[{"coaCode":"SREV","Value":"2792.000000"},{"coaCode":"RTLR","Value":"2792.000000"},{"coaCode":"SCOR","Value":"211.000000"},{"coaCode":"SGRP","Value":"2581.000000"},{"coaCode":"SSGA","Value":"1732.000000"},{"coaCode":"SDPR","Value":"359.000000"},{"coaCode":"SINN","Value":"53.000000"},{"coaCode":"SOOE","Value":"-30.000000"},{"coaCode":"ETOE","Value":"2325.000000"},{"coaCode":"SOPI","Value":"467.000000"},{"coaCode":"SNIN","Value":"-139.000000"},{"coaCode":"SONT","Value":"-3.000000"},{"coaCode":"EIBT","Value":"325.000000"},{"coaCode":"TTAX","Value":"-22.000000"},{"coaCode":"TIAT","Value":"347.000000"},{"coaCode":"CMIN","Value":"-18.000000"},{"coaCode":"CEIA","Value":"2.000000"},{"coaCode":"NIBX","Value":"331.000000"},{"coaCode":"STXI","Value":"-1.000000"},{"coaCode":"NINC","Value":"330.000000"},{"coaCode":"SANI","Value":"-1.000000"},{"coaCode":"CIAC","Value":"330.000000"},{"coaCode":"XNIC","Value":"329.000000"},{"coaCode":"SDAJ","Value":"0.000000"},{"coaCode":"SDNI","Value":"329.000000"},{"coaCode":"SDWS","Value":"716.900130"},{"coaCode":"SDBF","Value":"0.460320"},{"coaCode":"DDPS1","Value":"0.345000"},{"coaCode":"VDES","Value":"0.460320"}]},{"Type":"BAL","FPHeader":{"UpdateType":{"Code":"UPD","Value":"Updated Normal"},"StatementDate":"2017-09-30","Source":{"Date":"2017-11-03","Value":"Interim Report"}},"lineItem":[{"coaCode":"ACAE","Value":"898.000000"},{"coaCode":"ASTI","Value":"81.000000"},{"coaCode":"SCSI","Value":"979.000000"},{"coaCode":"AACR","Value":"1530.000000"},{"coaCode":"ATRC","Value":"1530.000000"},{"coaCode":"APPY","Value":"724.000000"},{"coaCode":"SOCA","Value":"25.000000"},{"coaCode":"ATCA","Value":"3258.000000"},{"coaCode":"APPN","Value":"903.000000"},{"coaCode":"AGWI","Value":"15019.000000"},{"coaCode":"AINT","Value":"6840.000000"},{"coaCode":"SINV","Value":"258.000000"},{"coaCode":"SOLA","Value":"487.000000"},{"coaCode":"ATOT","Value":"26765.000000"},{"coaCode":"LAPB","Value":"252.000000"},{"coaCode":"LAEX","Value":"1404.000000"},{"coaCode":"LSTD","Value":"705.000000"},{"coaCode":"LCLD","Value":"1283.000000"},{"coaCode":"SOCL","Value":"1548.000000"},{"coaCode":"LTCL","Value":"5192.000000"},{"coaCode":"LLTD","Value":"5384.000000"},{"coaCode":"LTTD","Value":"5384.000000"},{"coaCode":"STLD","Value":"7372.000000"},{"coaCode":"SBDT","Value":"987.000000"},{"coaCode":"LMIN","Value":"494.000000"},{"coaCode":"SLTL","Value":"1964.000000"},{"coaCode":"LTLL","Value":"14021.000000"},{"coaCode":"SCMS","Value":"9287.000000"},{"coaCode":"QPIC","Value":"249.000000"},{"coaCode":"QRED","Value":"6920.000000"},{"coaCode":"SOTE","Value":"-3712.000000"},{"coaCode":"QTLE","Value":"12744.000000"},{"coaCode":"QTEL","Value":"26765.000000"},{"coaCode":"QTCO","Value":"711.559700"},{"coaCode":"QTPO","Value":"6.000000"},{"coaCode":"STBP","Value":"-12.809890"}]},{"Type":"CAS","FPHeader":{"PeriodLength":9,"periodType":{"Code":"M","Value":"Months"},"UpdateType":{"Code":"UPD","Value":"Updated Normal"},"StatementDate":"2017-09-30","Source":{"Date":"2017-11-03","Value":"Interim Report"}},"lineItem":[{"coaCode":"ONET","Value":"867.000000"},{"coaCode":"SDED","Value":"222.000000"},{"coaCode":"SAMT","Value":"873.000000"},{"coaCode":"OBDT","Value":"-194.000000"},{"coaCode":"SNCI","Value":"12.000000"},{"coaCode":"SCIP","Value":"218.000000"},{"coaCode":"SOCF","Value":"-506.000000"},{"coaCode":"OTLO","Value":"1274.000000"},{"coaCode":"SCEX","Value":"-710.000000"},{"coaCode":"SICF","Value":"-103.000000"},{"coaCode":"ITLI","Value":"-813.000000"},{"coaCode":"SFCF","Value":"-20.000000"},{"coaCode":"FCDP","Value":"-722.000000"},{"coaCode":"FPSS","Value":"-808.000000"},{"coaCode":"FPRD","Value":"-395.000000"},{"coaCode":"FTLF","Value":"-1945.000000"},{"coaCode":"SFEE","Value":"9.000000"},{"coaCode":"SNCC","Value":"-1475.000000"}]}]},{"Type":"Interim","EndDate":"2017-06-30","FiscalYear":"2017","FiscalPeriodNumber":2,"Statement":[{"Type":"INC","FPHeader":{"PeriodLength":3,"periodType":{"Code":"M","Value":"Months"},"UpdateType":{"Code":"UPD","Value":"Updated Normal"},"StatementDate":"2017-06-30","Source":{"Date":"2017-08-03","Value":"Interim Report"}},"lineItem":[{"coaCode":"SREV","Value":"2782.000000"},{"coaCode":"RTLR","Value":"2782.000000"},{"coaCode":"SCOR","Value":"210.000000"},{"coaCode":"SGRP","Value":"2572.000000"},{"coaCode":"SSGA","Value":"1734.000000"},{"coaCode":"SDPR","Value":"365.000000"},{"coaCode":"SINN","Value":"53.000000"},{"coaCode":"SOOE","Value":"21.000000"},{"coaCode":"ETOE","Value":"2383.000000"},{"coaCode":"SOPI","Value":"399.000000"},{"coaCode":"SNIN","Value":"-173.000000"},{"coaCode":"SONT","Value":"-13.000000"},{"coaCode":"EIBT","Value":"213.000000"},{"coaCode":"TTAX","Value":"5.000000"},{"coaCode":"TIAT","Value":"208.000000"},{"coaCode":"CMIN","Value":"-14.000000"},{"coaCode":"CEIA","Value":"-7.000000"},{"coaCode":"NIBX","Value":"187.000000"},{"coaCode":"STXI","Value":"5.000000"},{"coaCode":"NINC","Value":"192.000000"},{"coaCode":"SANI","Value":"0.000000"},{"coaCode":"CIAC","Value":"187.000000"},{"coaCode":"XNIC","Value":"192.000000"},{"coaCode":"SDNI","Value":"192.000000"},{"coaCode":"SDWS","Value":"722.504110"},{"coaCode":"SDBF","Value":"0.258820"},{"coaCode":"DDPS1","Value":"0.345000"},{"coaCode":"VDES","Value":"0.258820"}]},{"Type":"BAL","FPHeader":{"UpdateType":{"Code":"UPD","Value":"Updated Normal"},"StatementDate":"2017-06-30","Source":{"Date":"2017-08-03","Value":"Interim Report"}},"lineItem":[{"coaCode":"ACAE","Value":"771.000000"},{"coaCode":"ASTI","Value":"42.000000"},{"coaCode":"SCSI","Value":"813.000000"},{"coaCode":"AACR","Value":"1545.000000"},{"coaCode":"ATRC","Value":"1545.000000"},{"coaCode":"APPY","Value":"735.000000"},{"coaCode":"SOCA","Value":"44.000000"},{"coaCode":"ATCA","Value":"3137.000000"},{"coaCode":"APPN","Value":"877.000000"},{"coaCode":"AGWI","Value":"14856.000000"},{"coaCode":"AINT","Value":"6943.000000"},{"coaCode":"SINV","Value":"252.000000"},{"coaCode":"SOLA","Value":"452.000000"},{"coaCode":"ATOT","Value":"26517.000000"},{"coaCode":"LAPB","Value":"255.000000"},{"coaCode":"LAEX","Value":"1241.000000"},{"coaCode":"LSTD","Value":"150.000000"},{"coaCode":"LCLD","Value":"726.000000"},{"coaCode":"SOCL","Value":"1591.000000"},{"coaCode":"LTCL","Value":"3963.000000"},{"coaCode":"LLTD","Value":"6327.000000"},{"coaCode":"LTTD","Value":"6327.000000"},{"coaCode":"STLD","Value":"7203.000000"},{"coaCode":"SBDT","Value":"1093.000000"},{"coaCode":"LMIN","Value":"494.000000"},{"coaCode":"SLTL","Value":"2001.000000"},{"coaCode":"LTLL","Value":"13878.000000"},{"coaCode":"SCMS","Value":"9327.000000"},{"coaCode":"QPIC","Value":"244.000000"},{"coaCode":"QRED","Value":"6990.000000"},{"coaCode":"SOTE","Value":"-3922.000000"},{"coaCode":"QTLE","Value":"12639.000000"},{"coaCode":"QTEL","Value":"26517.000000"},{"coaCode":"QTCO","Value":"714.704380"},{"coaCode":"QTPO","Value":"6.000000"},{"coaCode":"STBP","Value":"-12.816490"}]},{"Type":"CAS","FPHeader":{"PeriodLength":6,"periodType":{"Code":"M","Value":"Months"},"UpdateType":{"Code":"UPD","Value":"Updated Normal"},"StatementDate":"2017-06-30","Source":{"Date":"2017-08-03","Value":"Interim Report"}},"lineItem":[{"coaCode":"ONET","Value":"518.000000"},{"coaCode":"SDED","Value":"149.000000"},{"coaCode":"SAMT","Value":"587.000000"},{"coaCode":"OBDT","Value":"-73.000000"},{"coaCode":"SNCI","Value":"-112.000000"},{"coaCode":"SCIP","Value":"165.000000"},{"coaCode":"SOCF","Value":"-603.000000"},{"coaCode":"OTLO","Value":"466.000000"},{"coaCode":"SCEX","Value":"-454.000000"},{"coaCode":"SICF","Value":"-141.000000"},{"coaCode":"ITLI","Value":"-595.000000"},{"coaCode":"SFCF","Value":"-15.000000"},{"coaCode":"FCDP","Value":"-484.000000"},{"coaCode":"FPSS","Value":"-578.000000"},{"coaCode":"FPRD","Value":"-400.000000"},{"coaCode":"FTLF","Value":"-1477.000000"},{"coaCode":"SFEE","Value":"5.000000"},{"coaCode":"SNCC","Value":"-1601.000000"}]}]},{"Type":"Interim","EndDate":"2017-03-31","FiscalYear":"2017","FiscalPeriodNumber":1,"Statement":[{"Type":"INC","FPHeader":{"PeriodLength":3,"periodType":{"Code":"M","Value":"Months"},"UpdateType":{"Code":"UPD","Value":"Updated Normal"},"StatementDate":"2017-03-31","Source":{"Date":"2017-05-01","Value":"Interim Report"}},"lineItem":[{"coaCode":"SREV","Value":"2815.000000"},{"coaCode":"RTLR","Value":"2815.000000"},{"coaCode":"SCOR","Value":"198.000000"},{"coaCode":"SGRP","Value":"2617.000000"},{"coaCode":"SSGA","Value":"1741.000000"},{"coaCode":"SDPR","Value":"371.000000"},{"coaCode":"SINN","Value":"65.000000"},{"coaCode":"SOOE","Value":"-4.000000"},{"coaCode":"ETOE","Value":"2371.000000"},{"coaCode":"SOPI","Value":"444.000000"},{"coaCode":"SNIN","Value":"-107.000000"},{"coaCode":"SONT","Value":"-13.000000"},{"coaCode":"EIBT","Value":"324.000000"},{"coaCode":"TTAX","Value":"9.000000"},{"coaCode":"TIAT","Value":"315.000000"},{"coaCode":"CMIN","Value":"-17.000000"},{"coaCode":"CEIA","Value":"2.000000"},{"coaCode":"NIBX","Value":"300.000000"},{"coaCode":"STXI","Value":"-3.000000"},{"coaCode":"NINC","Value":"297.000000"},{"coaCode":"SANI","Value":"-1.000000"},{"coaCode":"CIAC","Value":"299.000000"},{"coaCode":"XNIC","Value":"296.000000"},{"coaCode":"SDAJ","Value":"0.000000"},{"coaCode":"SDNI","Value":"296.000000"},{"coaCode":"SDWS","Value":"729.194400"},{"coaCode":"SDBF","Value":"0.410040"},{"coaCode":"DDPS1","Value":"0.345000"},{"coaCode":"VDES","Value":"0.410040"}]},{"Type":"BAL","FPHeader":{"UpdateType":{"Code":"UPD","Value":"Updated Normal"},"StatementDate":"2017-03-31","Source":{"Date":"2017-05-01","Value":"Interim Report"}},"lineItem":[{"coaCode":"ACAE","Value":"812.000000"},{"coaCode":"ASTI","Value":"49.000000"},{"coaCode":"SCSI","Value":"861.000000"},{"coaCode":"AACR","Value":"1573.000000"},{"coaCode":"ATRC","Value":"1573.000000"},{"coaCode":"APPY","Value":"740.000000"},{"coaCode":"SOCA","Value":"82.000000"},{"coaCode":"ATCA","Value":"3256.000000"},{"coaCode":"APPN","Value":"937.000000"},{"coaCode":"AGWI","Value":"14673.000000"},{"coaCode":"AINT","Value":"7018.000000"},{"coaCode":"SINV","Value":"259.000000"},{"coaCode":"SOLA","Value":"463.000000"},{"coaCode":"ATOT","Value":"26606.000000"},{"coaCode":"LAPB","Value":"275.000000"},{"coaCode":"LAEX","Value":"1226.000000"},{"coaCode":"LSTD","Value":"255.000000"},{"coaCode":"LCLD","Value":"674.000000"},{"coaCode":"SOCL","Value":"1531.000000"},{"coaCode":"LTCL","Value":"3961.000000"},{"coaCode":"LLTD","Value":"6290.000000"},{"coaCode":"LTTD","Value":"6290.000000"},{"coaCode":"STLD","Value":"7219.000000"},{"coaCode":"SBDT","Value":"1130.000000"},{"coaCode":"LMIN","Value":"492.000000"},{"coaCode":"SLTL","Value":"1990.000000"},{"coaCode":"LTLL","Value":"13863.000000"},{"coaCode":"SCMS","Value":"9393.000000"},{"coaCode":"QPIC","Value":"224.000000"},{"coaCode":"QRED","Value":"7284.000000"},{"coaCode":"SOTE","Value":"-4158.000000"},{"coaCode":"QTLE","Value":"12743.000000"},{"coaCode":"QTEL","Value":"26606.000000"},{"coaCode":"QTCO","Value":"721.850620"},{"coaCode":"QTPO","Value":"6.000000"},{"coaCode":"STBP","Value":"-12.395920"}]},{"Type":"CAS","FPHeader":{"PeriodLength":3,"periodType":{"Code":"M","Value":"Months"},"UpdateType":{"Code":"UPD","Value":"Updated Normal"},"StatementDate":"2017-03-31","Source":{"Date":"2017-05-01","Value":"Interim Report"}},"lineItem":[{"coaCode":"ONET","Value":"317.000000"},{"coaCode":"SDED","Value":"72.000000"},{"coaCode":"SAMT","Value":"299.000000"},{"coaCode":"OBDT","Value":"-21.000000"},{"coaCode":"SNCI","Value":"-378.000000"},{"coaCode":"SCTP","Value":"62.000000"},{"coaCode":"SCIP","Value":"69.000000"},{"coaCode":"SOCF","Value":"-657.000000"},{"coaCode":"OTLO","Value":"-368.000000"},{"coaCode":"SCEX","Value":"-213.000000"},{"coaCode":"SICF","Value":"-162.000000"},{"coaCode":"ITLI","Value":"-375.000000"},{"coaCode":"SFCF","Value":"-4.000000"},{"coaCode":"FCDP","Value":"-243.000000"},{"coaCode":"FPSS","Value":"-284.000000"},{"coaCode":"FPRD","Value":"-295.000000"},{"coaCode":"FTLF","Value":"-826.000000"},{"coaCode":"SFEE","Value":"2.000000"},{"coaCode":"SNCC","Value":"-1567.000000"}]}]},{"Type":"Interim","EndDate":"2016-12-31","FiscalYear":"2016","FiscalPeriodNumber":4,"Statement":[{"Type":"INC","FPHeader":{"PeriodLength":3,"periodType":{"Code":"M","Value":"Months"},"UpdateType":{"Code":"UCA","Value":"Updated Calculated"},"StatementDate":"2016-12-31","AuditorName":{"Code":"PWCL","Value":"PricewaterhouseCoopers LLP"},"AuditorOpinion":{"Code":"UNQ","Value":"Unqualified"},"Source":{"Date":"2017-03-09","Value":"ARS"}},"lineItem":[{"coaCode":"SREV","Value":"2860.000000"},{"coaCode":"RTLR","Value":"2860.000000"},{"coaCode":"SCOR","Value":"206.000000"},{"coaCode":"SGRP","Value":"2654.000000"},{"coaCode":"SSGA","Value":"2019.000000"},{"coaCode":"SDPR","Value":"407.000000"},{"coaCode":"SINN","Value":"-57.000000"},{"coaCode":"SUIE","Value":"-31.000000"},{"coaCode":"SOOE","Value":"22.000000"},{"coaCode":"ETOE","Value":"2566.000000"},{"coaCode":"SOPI","Value":"294.000000"},{"coaCode":"SNIN","Value":"-3.000000"},{"coaCode":"SONT","Value":"-18.000000"},{"coaCode":"EIBT","Value":"273.000000"},{"coaCode":"TTAX","Value":"1.000000"},{"coaCode":"TIAT","Value":"272.000000"},{"coaCode":"CMIN","Value":"-15.000000"},{"coaCode":"CEIA","Value":"2.000000"},{"coaCode":"NIBX","Value":"259.000000"},{"coaCode":"STXI","Value":"1967.000000"},{"coaCode":"NINC","Value":"2226.000000"},{"coaCode":"SANI","Value":"0.000000"},{"coaCode":"CIAC","Value":"259.000000"},{"coaCode":"XNIC","Value":"2226.000000"},{"coaCode":"SDNI","Value":"2226.000000"},{"coaCode":"SDWS","Value":"734.096180"},{"coaCode":"SDBF","Value":"0.352810"},{"coaCode":"DDPS1","Value":"0.340000"},{"coaCode":"VDES","Value":"0.598470"}]},{"Type":"BAL","FPHeader":{"UpdateType":{"Code":"UPD","Value":"Updated Normal"},"StatementDate":"2016-12-31","AuditorName":{"Code":"PWCL","Value":"PricewaterhouseCoopers LLP"},"AuditorOpinion":{"Code":"UNQ","Value":"Unqualified"},"Source":{"Date":"2017-03-09","Value":"ARS"}},"lineItem":[{"coaCode":"ACAE","Value":"2368.000000"},{"coaCode":"ASTI","Value":"67.000000"},{"coaCode":"SCSI","Value":"2435.000000"},{"coaCode":"AACR","Value":"1392.000000"},{"coaCode":"ATRC","Value":"1392.000000"},{"coaCode":"APPY","Value":"686.000000"},{"coaCode":"SOCA","Value":"121.000000"},{"coaCode":"ATCA","Value":"4634.000000"},{"coaCode":"APPN","Value":"961.000000"},{"coaCode":"AGWI","Value":"14485.000000"},{"coaCode":"AINT","Value":"7049.000000"},{"coaCode":"SINV","Value":"251.000000"},{"coaCode":"SOLA","Value":"472.000000"},{"coaCode":"ATOT","Value":"27852.000000"},{"coaCode":"LAPB","Value":"311.000000"},{"coaCode":"LAEX","Value":"1517.000000"},{"coaCode":"LSTD","Value":"0.000000"},{"coaCode":"LCLD","Value":"1179.000000"},{"coaCode":"SOCL","Value":"1555.000000"},{"coaCode":"LTCL","Value":"4562.000000"},{"coaCode":"LLTD","Value":"6279.000000"},{"coaCode":"LTTD","Value":"6279.000000"},{"coaCode":"STLD","Value":"7458.000000"},{"coaCode":"SBDT","Value":"1158.000000"},{"coaCode":"LMIN","Value":"483.000000"},{"coaCode":"SLTL","Value":"2597.000000"},{"coaCode":"LTLL","Value":"15079.000000"},{"coaCode":"SCMS","Value":"9393.000000"},{"coaCode":"QPIC","Value":"196.000000"},{"coaCode":"QRED","Value":"7477.000000"},{"coaCode":"SOTE","Value":"-4293.000000"},{"coaCode":"QTLE","Value":"12773.000000"},{"coaCode":"QTEL","Value":"27852.000000"},{"coaCode":"QTCO","Value":"727.443300"},{"coaCode":"QTPO","Value":"6.000000"},{"coaCode":"STBP","Value":"-12.043550"}]},{"Type":"CAS","FPHeader":{"PeriodLength":12,"periodType":{"Code":"M","Value":"Months"},"UpdateType":{"Code":"UPD","Value":"Updated Normal"},"StatementDate":"2016-12-31","AuditorName":{"Code":"PWCL","Value":"PricewaterhouseCoopers LLP"},"AuditorOpinion":{"Code":"UNQ","Value":"Unqualified"},"Source":{"Date":"2017-03-09","Value":"ARS"}},"lineItem":[{"coaCode":"ONET","Value":"1056.000000"},{"coaCode":"SDED","Value":"313.000000"},{"coaCode":"SAMT","Value":"1239.000000"},{"coaCode":"OBDT","Value":"-11.000000"},{"coaCode":"SNCI","Value":"369.000000"},{"coaCode":"SCTP","Value":"347.000000"},{"coaCode":"SCIP","Value":"347.000000"},{"coaCode":"SOCF","Value":"18.000000"},{"coaCode":"OTLO","Value":"2984.000000"},{"coaCode":"SCEX","Value":"-905.000000"},{"coaCode":"SICF","Value":"3091.000000"},{"coaCode":"ITLI","Value":"2186.000000"},{"coaCode":"SFCF","Value":"-14.000000"},{"coaCode":"FCDP","Value":"-982.000000"},{"coaCode":"FPSS","Value":"-1673.000000"},{"coaCode":"FPRD","Value":"-1043.000000"},{"coaCode":"FTLF","Value":"-3712.000000"},{"coaCode":"SFEE","Value":"-13.000000"},{"coaCode":"SNCC","Value":"1445.000000"}]}]},{"Type":"Interim","EndDate":"2016-09-30","FiscalYear":"2016","FiscalPeriodNumber":3,"Statement":[{"Type":"INC","FPHeader":{"PeriodLength":3,"periodType":{"Code":"M","Value":"Months"},"UpdateType":{"Code":"UPD","Value":"Updated Normal"},"StatementDate":"2016-09-30","Source":{"Date":"2016-11-03","Value":"Interim Report"}},"lineItem":[{"coaCode":"SREV","Value":"2744.000000"},{"coaCode":"RTLR","Value":"2744.000000"},{"coaCode":"SCOR","Value":"206.000000"},{"coaCode":"SGRP","Value":"2538.000000"},{"coaCode":"SSGA","Value":"1724.000000"},{"coaCode":"SDPR","Value":"383.000000"},{"coaCode":"SINN","Value":"34.000000"},{"coaCode":"SOOE","Value":"12.000000"},{"coaCode":"ETOE","Value":"2359.000000"},{"coaCode":"SOPI","Value":"385.000000"},{"coaCode":"SNIN","Value":"-91.000000"},{"coaCode":"SONT","Value":"-20.000000"},{"coaCode":"EIBT","Value":"274.000000"},{"coaCode":"TTAX","Value":"8.000000"},{"coaCode":"TIAT","Value":"266.000000"},{"coaCode":"CMIN","Value":"-13.000000"},{"coaCode":"CEIA","Value":"2.000000"},{"coaCode":"NIBX","Value":"255.000000"},{"coaCode":"STXI","Value":"18.000000"},{"coaCode":"NINC","Value":"273.000000"},{"coaCode":"SANI","Value":"-1.000000"},{"coaCode":"CIAC","Value":"254.000000"},{"coaCode":"XNIC","Value":"272.000000"},{"coaCode":"SDNI","Value":"272.000000"},{"coaCode":"SDWS","Value":"745.772210"},{"coaCode":"SDBF","Value":"0.340590"},{"coaCode":"DDPS1","Value":"0.340000"},{"coaCode":"VDES","Value":"0.340590"}]},{"Type":"BAL","FPHeader":{"UpdateType":{"Code":"UPD","Value":"Updated Normal"},"StatementDate":"2016-09-30","Source":{"Date":"2016-11-03","Value":"Interim Report"}},"lineItem":[{"coaCode":"ACAE","Value":"831.000000"},{"coaCode":"ASTI","Value":"54.000000"},{"coaCode":"SCSI","Value":"885.000000"},{"coaCode":"AACR","Value":"1403.000000"},{"coaCode":"ATRC","Value":"1403.000000"},{"coaCode":"APPY","Value":"668.000000"},{"coaCode":"SOCA","Value":"1745.000000"},{"coaCode":"ATCA","Value":"4701.000000"},{"coaCode":"APPN","Value":"943.000000"},{"coaCode":"AGWI","Value":"14795.000000"},{"coaCode":"AINT","Value":"7261.000000"},{"coaCode":"SINV","Value":"246.000000"},{"coaCode":"SOLA","Value":"467.000000"},{"coaCode":"ATOT","Value":"28413.000000"},{"coaCode":"LAPB","Value":"222.000000"},{"coaCode":"LAEX","Value":"1415.000000"},{"coaCode":"LSTD","Value":"0.000000"},{"coaCode":"LCLD","Value":"2995.000000"},{"coaCode":"SOCL","Value":"1914.000000"},{"coaCode":"LTCL","Value":"6546.000000"},{"coaCode":"LLTD","Value":"6308.000000"},{"coaCode":"LTTD","Value":"6308.000000"},{"coaCode":"STLD","Value":"9303.000000"},{"coaCode":"SBDT","Value":"982.000000"},{"coaCode":"LMIN","Value":"482.000000"},{"coaCode":"SLTL","Value":"2747.000000"},{"coaCode":"LTLL","Value":"17065.000000"},{"coaCode":"SCMS","Value":"9444.000000"},{"coaCode":"QPIC","Value":"183.000000"},{"coaCode":"QRED","Value":"5599.000000"},{"coaCode":"SOTE","Value":"-3878.000000"},{"coaCode":"QTLE","Value":"11348.000000"},{"coaCode":"QTEL","Value":"28413.000000"},{"coaCode":"QTCO","Value":"734.727090"},{"coaCode":"QTPO","Value":"6.000000"},{"coaCode":"STBP","Value":"-14.574120"}]},{"Type":"CAS","FPHeader":{"PeriodLength":9,"periodType":{"Code":"M","Value":"Months"},"UpdateType":{"Code":"UPD","Value":"Updated Normal"},"StatementDate":"2016-09-30","Source":{"Date":"2016-11-03","Value":"Interim Report"}},"lineItem":[{"coaCode":"ONET","Value":"782.000000"},{"coaCode":"SDED","Value":"239.000000"},{"coaCode":"SAMT","Value":"906.000000"},{"coaCode":"OBDT","Value":"-130.000000"},{"coaCode":"SNCI","Value":"533.000000"},{"coaCode":"SCTP","Value":"120.000000"},{"coaCode":"SCIP","Value":"240.000000"},{"coaCode":"SOCF","Value":"-344.000000"},{"coaCode":"OTLO","Value":"1986.000000"},{"coaCode":"SCEX","Value":"-658.000000"},{"coaCode":"SICF","Value":"-122.000000"},{"coaCode":"ITLI","Value":"-780.000000"},{"coaCode":"SFCF","Value":"-22.000000"},{"coaCode":"FCDP","Value":"-742.000000"},{"coaCode":"FPSS","Value":"-1232.000000"},{"coaCode":"FPRD","Value":"697.000000"},{"coaCode":"FTLF","Value":"-1299.000000"},{"coaCode":"SFEE","Value":"-3.000000"},{"coaCode":"SNCC","Value":"-96.000000"}]}]}]}}})} ),

	
	// send trkd fin request, get a promise back with <html-div>
	getStatementsDiv: (ric, className="fin1") => {
		return finObj.getStatementsJSON(ric)
			.then(q => {
				let acrToNames = {};
				// extract all the data points from the response object
				q.FinancialStatements.COAMap.mapItem.forEach(o => {acrToNames[o.coaItem] = o.Value});
				
				let latestFiscPeriod = q.FinancialStatements.AnnualPeriods.FiscalPeriod[0];

				var generateDiv = (id, stType, index) => {
					let divContent = "";
					latestFiscPeriod.Statement[index].lineItem.forEach(o => {
						divContent += `<div class="pt"><span class="lb">${acrToNames[o.coaCode]}</span><span class="vl">${o.Value}</span></div>`;
					});
					
					return `<div id="${id}"><div class="hdr"><span class="lb">${stType}</span><span class="vl">FiscalYear: ${latestFiscPeriod.FiscalYear}</span></div>${divContent}</div>`;
				};
				
				return `${generateDiv("income", "Income Statement", 0)}
					${generateDiv("balance", "Balance Statement", 1)}
					${generateDiv("cashflow", "Cash Flow Statement", 2)}`;
				
			})
			.catch(error => {
				return `<div class="${className}"><b>Error: ${error}</b></div>`;
			});

	}
};


